==> ejc-scene-impl-3.0.0-20211013.065558-3-sources.jar: com/ejianc/business/scene/bean/SceneCheckEntity.java <==
package com.ejianc.business.scene.bean;

import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;
import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;
import com.ejianc.framework.skeleton.template.annotation.SubEntity;

import com.ejianc.business.scene.bean.SceneCheckDetailEntity;
/**
 * 检查单主表
 * 
 * @author generator
 * 
 */
 @TableName("ejc_scene_check")
public class SceneCheckEntity extends BaseEntity {
    private static final long serialVersionUID = 1L;
    
    @TableField(value="bill_code")
    private java.lang.String billCode; // 单据编号
    @TableField(value="project_id")
    private java.lang.Long projectId; // 项目id
    @TableField(value="project_name")
    private java.lang.String projectName; // 项目名称
    @TableField(value="org_id")
    private java.lang.Long orgId; // 组织id
    @TableField(value="org_name")
    private java.lang.String orgName; // 组织名
    @TableField(value="check_name")
    private java.lang.String checkName; // 检查名称
    @TableField(value="check_type")
    private java.lang.Integer checkType; // 检查类型 1、综合检查；2、安全检查；3、质量检查；4、进度检查；5、其他检查；
    @TableField(value="check_id")
    private java.lang.Long checkId; // 检查人id
    @TableField(value="check_person")
    private java.lang.String checkPerson; // 检查人
    @TableField(value="check_date")
    private java.util.Date checkDate; // 检查日期
    @TableField(value="finish_date")
    private java.util.Date finishDate; // 要求完成日期
    @TableField(value="reform_duty_id")
    private java.lang.Long reformDutyId; // 整改责任人id
    @TableField(value="reform_duty_person")
    private java.lang.String reformDutyPerson; // 整改责任人
    @TableField(value="review_id")
    private java.lang.Long reviewId; // 复查人id
    @TableField(value="review_person")
    private java.lang.String reviewPerson; // 复查人
    @TableField(value="notif_relevant_id")
    private java.lang.Long notifRelevantId; // 通知相关人员id
    @TableField(value="notif_relevant_person")
    private java.lang.String notifRelevantPerson; // 通知相关人员
    @TableField(value="reform_status")
    private java.lang.Integer reformStatus; // 整改状态：1、待整改（检查单审批通过，整改单未全部整改）；2、待复查（已全部整改，复查单未提交）；3、复查不合格（复查单提交后存在不合格项，部分项重新整改）；4、已完成（复查合格）；
    @TableField(value="review_status")
    private java.lang.Integer reviewStatus; // 复查状态：0-自由态，1-已提交
    @TableField(value="remarks")
    private java.lang.String remarks; // 备注
    @TableField(value="bill_state")
    private java.lang.Integer billState; // 单据状态：0自由态，1已提交，2审批中，3审批通过，4驳回，5提交后有人审批中
    
    
    @TableField(exist=false)
    @SubEntity(serviceName="sceneCheckDetailService")
    private List<SceneCheckDetailEntity> sceneCheckDetailEntities = new ArrayList<>(); // 检查单待检复检子表
    

    /**
     * 单据编号
     */
    public java.lang.String getBillCode() {
        return billCode;
    }

    /**
     * 单据编号
     */
    public void setBillCode(java.lang.String billCode) {
        this.billCode = billCode;
    }
    /**
     * 项目id
     */
    public java.lang.Long getProjectId() {
        return projectId;
    }

    /**
     * 项目id
     */
    public void setProjectId(java.lang.Long projectId) {
        this.projectId = projectId;
    }
    /**
     * 项目名称
     */
    public java.lang.String getProjectName() {
        return projectName;
    }

    /**
     * 项目名称
     */
    public void setProjectName(java.lang.String projectName) {
        this.projectName = projectName;
    }
    /**
     * 组织id
     */
    public java.lang.Long getOrgId() {
        return orgId;
    }

    /**
     * 组织id
     */
    public void setOrgId(java.lang.Long orgId) {
        this.orgId = orgId;
    }
    /**
     * 组织名
     */
    public java.lang.String getOrgName() {
        return orgName;
    }

    /**
     * 组织名
     */
    public void setOrgName(java.lang.String orgName) {
        this.orgName = orgName;
    }
    /**
     * 检查名称
     */
    public java.lang.String getCheckName() {
        return checkName;
    }

    /**
     * 检查名称
     */
    public void setCheckName(java.lang.String checkName) {
        this.checkName = checkName;
    }
    /**
     * 检查类型 1、综合检查；2、安全检查；3、质量检查；4、进度检查；5、其他检查；
     */
    public java.lang.Integer getCheckType() {
        return checkType;
    }

    /**
     * 检查类型 1、综合检查；2、安全检查；3、质量检查；4、进度检查；5、其他检查；
     */
    public void setCheckType(java.lang.Integer checkType) {
        this.checkType = checkType;
    }
    /**
     * 检查人id
     */
    public java.lang.Long getCheckId() {
        return checkId;
    }

    /**
     * 检查人id
     */
    public void setCheckId(java.lang.Long checkId) {
        this.checkId = checkId;
    }
    /**
     * 检查人
     */
    public java.lang.String getCheckPerson() {
        return checkPerson;
    }

    /**
     * 检查人
     */
    public void setCheckPerson(java.lang.String checkPerson) {
        this.checkPerson = checkPerson;
    }
    /**
     * 检查日期
     */
    public java.util.Date getCheckDate() {
        return checkDate;
    }

    /**
     * 检查日期
     */
    public void setCheckDate(java.util.Date checkDate) {
        this.checkDate = checkDate;
    }
    /**
     * 要求完成日期
     */
    public java.util.Date getFinishDate() {
        return finishDate;
    }

    /**
     * 要求完成日期
     */
    public void setFinishDate(java.util.Date finishDate) {
        this.finishDate = finishDate;
    }
    /**
     * 整改责任人id
     */
    public java.lang.Long getReformDutyId() {
        return reformDutyId;
    }

    /**
     * 整改责任人id
     */
    public void setReformDutyId(java.lang.Long reformDutyId) {
        this.reformDutyId = reformDutyId;
    }
    /**
     * 整改责任人
     */
    public java.lang.String getReformDutyPerson() {
        return reformDutyPerson;
    }

    /**
     * 整改责任人
     */
    public void setReformDutyPerson(java.lang.String reformDutyPerson) {
        this.reformDutyPerson = reformDutyPerson;
    }
    /**
     * 复查人id
     */
    public java.lang.Long getReviewId() {
        return reviewId;
    }

    /**
     * 复查人id
     */
    public void setReviewId(java.lang.Long reviewId) {
        this.reviewId = reviewId;
    }
    /**
     * 复查人
     */
    public java.lang.String getReviewPerson() {
        return reviewPerson;
    }

    /**
     * 复查人
     */
    public void setReviewPerson(java.lang.String reviewPerson) {
        this.reviewPerson = reviewPerson;
    }
    /**
     * 通知相关人员id
     */
    public java.lang.Long getNotifRelevantId() {
        return notifRelevantId;
    }

    /**
     * 通知相关人员id
     */
    public void setNotifRelevantId(java.lang.Long notifRelevantId) {
        this.notifRelevantId = notifRelevantId;
    }
    /**
     * 通知相关人员
     */
    public java.lang.String getNotifRelevantPerson() {
        return notifRelevantPerson;
    }

    /**
     * 通知相关人员
     */
    public void setNotifRelevantPerson(java.lang.String notifRelevantPerson) {
        this.notifRelevantPerson = notifRelevantPerson;
    }
    /**
     * 整改状态：1、待整改（检查单审批通过，整改单未全部整改）；2、待复查（已全部整改，复查单未提交）；3、复查不合格（复查单提交后存在不合格项，部分项重新整改）；4、已完成（复查合格）；
     */
    public java.lang.Integer getReformStatus() {
        return reformStatus;
    }

    /**
     * 整改状态：1、待整改（检查单审批通过，整改单未全部整改）；2、待复查（已全部整改，复查单未提交）；3、复查不合格（复查单提交后存在不合格项，部分项重新整改）；4、已完成（复查合格）；
     */
    public void setReformStatus(java.lang.Integer reformStatus) {
        this.reformStatus = reformStatus;
    }
    /**
     * 复查状态：0-自由态，1-已提交
     */
    public java.lang.Integer getReviewStatus() {
        return reviewStatus;
    }

    /**
     * 复查状态：0-自由态，1-已提交
     */
    public void setReviewStatus(java.lang.Integer reviewStatus) {
        this.reviewStatus = reviewStatus;
    }
    /**
     * 备注
     */
    public java.lang.String getRemarks() {
        return remarks;
    }

    /**
     * 备注
     */
    public void setRemarks(java.lang.String remarks) {
        this.remarks = remarks;
    }
    /**
     * 单据状态：0自由态，1已提交，2审批中，3审批通过，4驳回，5提交后有人审批中
     */
    public java.lang.Integer getBillState() {
        return billState;
    }

    /**
     * 单据状态：0自由态，1已提交，2审批中，3审批通过，4驳回，5提交后有人审批中
     */
    public void setBillState(java.lang.Integer billState) {
        this.billState = billState;
    }
    
    /**
     * 检查单待检复检子表
     */
    public List<SceneCheckDetailEntity> getSceneCheckDetailEntities() {
        return sceneCheckDetailEntities;
    }

    /**
     * 检查单待检复检子表
     */
    public void setSceneCheckDetailEntities(List<SceneCheckDetailEntity> sceneCheckDetailEntities) {
        this.sceneCheckDetailEntities = sceneCheckDetailEntities;
    }
}

==> ejc-scene-impl-3.0.0-20211013.084217-4-sources.jar: com/ejianc/business/scene/bean/SceneCheckEntity.java <==
package com.ejianc.business.scene.bean;

import java.util.Date;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;
import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;
import com.ejianc.framework.skeleton.template.annotation.SubEntity;

import com.ejianc.business.scene.bean.SceneCheckDetailEntity;
import com.fasterxml.jackson.annotation.JsonFormat;

/**
 * 检查单主表
 * 
 * @author generator
 * 
 */
 @TableName("ejc_scene_check")
public class SceneCheckEntity extends BaseEntity {
    private static final long serialVersionUID = 1L;
    
    @TableField(value="bill_code")
    private java.lang.String billCode; // 单据编号
    @TableField(value="project_id")
    private java.lang.Long projectId; // 项目id
    @TableField(value="project_name")
    private java.lang.String projectName; // 项目名称
    @TableField(value="org_id")
    private java.lang.Long orgId; // 组织id
    @TableField(value="org_name")
    private java.lang.String orgName; // 组织名
    @TableField(value="check_name")
    private java.lang.String checkName; // 检查名称
    @TableField(value="check_type")
    private java.lang.Integer checkType; // 检查类型 1、综合检查；2、安全检查；3、质量检查；4、进度检查；5、其他检查；
    @TableField(value="check_id")
    private java.lang.Long checkId; // 检查人id
    @TableField(value="check_person")
    private java.lang.String checkPerson; // 检查人
    @JsonFormat(
            shape = JsonFormat.Shape.STRING,
            pattern = "yyyy-MM-dd HH:mm:ss",
            timezone = "GMT+8"
    )
    @TableField(value="check_date")
    private java.util.Date checkDate; // 检查日期
    @JsonFormat(
            shape = JsonFormat.Shape.STRING,
            pattern = "yyyy-MM-dd HH:mm:ss",
            timezone = "GMT+8"
    )
    @TableField(value = "reform_finish_date")
    private java.util.Date reformFinishDate;//整改完成日期
    @JsonFormat(
            shape = JsonFormat.Shape.STRING,
            pattern = "yyyy-MM-dd HH:mm:ss",
            timezone = "GMT+8"
    )
    @TableField(value="finish_date")
    private java.util.Date finishDate; // 要求完成日期
    @TableField(value="reform_duty_id")
    private java.lang.Long reformDutyId; // 整改责任人id
    @TableField(value="reform_duty_person")
    private java.lang.String reformDutyPerson; // 整改责任人
    @TableField(value="review_id")
    private java.lang.Long reviewId; // 复查人id
    @TableField(value="review_person")
    private java.lang.String reviewPerson; // 复查人
    @TableField(value="notif_relevant_id")
    private java.lang.Long notifRelevantId; // 通知相关人员id
    @TableField(value="notif_relevant_person")
    private java.lang.String notifRelevantPerson; // 通知相关人员
    @TableField(value="reform_status")
    private java.lang.Integer reformStatus; // 整改状态：1、待整改（检查单审批通过，整改单未全部整改）；2、待复查（已全部整改，复查单未提交）；3、复查不合格（复查单提交后存在不合格项，部分项重新整改）；4、已完成（复查合格）；
    @TableField(value="review_status")
    private java.lang.Integer reviewStatus; // 复查状态：0-自由态，1-已提交
    @TableField(value="remarks")
    private java.lang.String remarks; // 备注
    @TableField(value="bill_state")
    private java.lang.Integer billState; // 单据状态：0自由态，1已提交，2审批中，3审批通过，4驳回，5提交后有人审批中
    
    
    @TableField(exist=false)
    @SubEntity(serviceName="sceneCheckDetailService")
    private List<SceneCheckDetailEntity> sceneCheckDetailEntities = new ArrayList<>(); // 检查单待检复检子表
    

    /**
     * 单据编号
     */
    public java.lang.String getBillCode() {
        return billCode;
    }

    /**
     * 单据编号
     */
    public void setBillCode(java.lang.String billCode) {
        this.billCode = billCode;
    }
    /**
     * 项目id
     */
    public java.lang.Long getProjectId() {
        return projectId;
    }

    /**
     * 项目id
     */
    public void setProjectId(java.lang.Long projectId) {
        this.projectId = projectId;
    }
    /**
     * 项目名称
     */
    public java.lang.String getProjectName() {
        return projectName;
    }

    /**
     * 项目名称
     */
    public void setProjectName(java.lang.String projectName) {
        this.projectName = projectName;
    }
    /**
     * 组织id
     */
    public java.lang.Long getOrgId() {
        return orgId;
    }

    /**
     * 组织id
     */
    public void setOrgId(java.lang.Long orgId) {
        this.orgId = orgId;
    }
    /**
     * 组织名
     */
    public java.lang.String getOrgName() {
        return orgName;
    }

    /**
     * 组织名
     */
    public void setOrgName(java.lang.String orgName) {
        this.orgName = orgName;
    }
    /**
     * 检查名称
     */
    public java.lang.String getCheckName() {
        return checkName;
    }

    /**
     * 检查名称
     */
    public void setCheckName(java.lang.String checkName) {
        this.checkName = checkName;
    }
    /**
     * 检查类型 1、综合检查；2、安全检查；3、质量检查；4、进度检查；5、其他检查；
     */
    public java.lang.Integer getCheckType() {
        return checkType;
    }

    /**
     * 检查类型 1、综合检查；2、安全检查；3、质量检查；4、进度检查；5、其他检查；
     */
    public void setCheckType(java.lang.Integer checkType) {
        this.checkType = checkType;
    }
    /**
     * 检查人id
     */
    public java.lang.Long getCheckId() {
        return checkId;
    }

    /**
     * 检查人id
     */
    public void setCheckId(java.lang.Long checkId) {
        this.checkId = checkId;
    }
    /**
     * 检查人
     */
    public java.lang.String getCheckPerson() {
        return checkPerson;
    }

    /**
     * 检查人
     */
    public void setCheckPerson(java.lang.String checkPerson) {
        this.checkPerson = checkPerson;
    }
    /**
     * 整改完成日期
     */
    public Date getReformFinishDate() {
        return reformFinishDate;
    }
    /**
     * 整改完成日期
     */
    public void setReformFinishDate(Date reformFinishDate) {
        this.reformFinishDate = reformFinishDate;
    }

    /**
     * 检查日期
     */


    public java.util.Date getCheckDate() {
        return checkDate;
    }

    /**
     * 检查日期
     */
    public void setCheckDate(java.util.Date checkDate) {
        this.checkDate = checkDate;
    }
    /**
     * 要求完成日期
     */
    public java.util.Date getFinishDate() {
        return finishDate;
    }

    /**
     * 要求完成日期
     */
    public void setFinishDate(java.util.Date finishDate) {
        this.finishDate = finishDate;
    }
    /**
     * 整改责任人id
     */
    public java.lang.Long getReformDutyId() {
        return reformDutyId;
    }

    /**
     * 整改责任人id
     */
    public void setReformDutyId(java.lang.Long reformDutyId) {
        this.reformDutyId = reformDutyId;
    }
    /**
     * 整改责任人
     */
    public java.lang.String getReformDutyPerson() {
        return reformDutyPerson;
    }

    /**
     * 整改责任人
     */
    public void setReformDutyPerson(java.lang.String reformDutyPerson) {
        this.reformDutyPerson = reformDutyPerson;
    }
    /**
     * 复查人id
     */
    public java.lang.Long getReviewId() {
        return reviewId;
    }

    /**
     * 复查人id
     */
    public void setReviewId(java.lang.Long reviewId) {
        this.reviewId = reviewId;
    }
    /**
     * 复查人
     */
    public java.lang.String getReviewPerson() {
        return reviewPerson;
    }

    /**
     * 复查人
     */
    public void setReviewPerson(java.lang.String reviewPerson) {
        this.reviewPerson = reviewPerson;
    }
    /**
     * 通知相关人员id
     */
    public java.lang.Long getNotifRelevantId() {
        return notifRelevantId;
    }

    /**
     * 通知相关人员id
     */
    public void setNotifRelevantId(java.lang.Long notifRelevantId) {
        this.notifRelevantId = notifRelevantId;
    }
    /**
     * 通知相关人员
     */
    public java.lang.String getNotifRelevantPerson() {
        return notifRelevantPerson;
    }

    /**
     * 通知相关人员
     */
    public void setNotifRelevantPerson(java.lang.String notifRelevantPerson) {
        this.notifRelevantPerson = notifRelevantPerson;
    }
    /**
     * 整改状态：1、待整改（检查单审批通过，整改单未全部整改）；2、待复查（已全部整改，复查单未提交）；3、复查不合格（复查单提交后存在不合格项，部分项重新整改）；4、已完成（复查合格）；
     */
    public java.lang.Integer getReformStatus() {
        return reformStatus;
    }

    /**
     * 整改状态：1、待整改（检查单审批通过，整改单未全部整改）；2、待复查（已全部整改，复查单未提交）；3、复查不合格（复查单提交后存在不合格项，部分项重新整改）；4、已完成（复查合格）；
     */
    public void setReformStatus(java.lang.Integer reformStatus) {
        this.reformStatus = reformStatus;
    }
    /**
     * 复查状态：0-自由态，1-已提交
     */
    public java.lang.Integer getReviewStatus() {
        return reviewStatus;
    }

    /**
     * 复查状态：0-自由态，1-已提交
     */
    public void setReviewStatus(java.lang.Integer reviewStatus) {
        this.reviewStatus = reviewStatus;
    }
    /**
     * 备注
     */
    public java.lang.String getRemarks() {
        return remarks;
    }

    /**
     * 备注
     */
    public void setRemarks(java.lang.String remarks) {
        this.remarks = remarks;
    }
    /**
     * 单据状态：0自由态，1已提交，2审批中，3审批通过，4驳回，5提交后有人审批中
     */
    public java.lang.Integer getBillState() {
        return billState;
    }

    /**
     * 单据状态：0自由态，1已提交，2审批中，3审批通过，4驳回，5提交后有人审批中
     */
    public void setBillState(java.lang.Integer billState) {
        this.billState = billState;
    }
    
    /**
     * 检查单待检复检子表
     */
    public List<SceneCheckDetailEntity> getSceneCheckDetailEntities() {
        return sceneCheckDetailEntities;
    }

    /**
     * 检查单待检复检子表
     */
    public void setSceneCheckDetailEntities(List<SceneCheckDetailEntity> sceneCheckDetailEntities) {
        this.sceneCheckDetailEntities = sceneCheckDetailEntities;
    }
}
